ISONAS Access Control System
============================

.. image:: https://travis-ci.org/vbastos/isonasacs.svg?branch=master
	:target: https://travis-ci.org/vbastos/isonasacs

API to communicate with the Crystal Matrix Software of ISONAS. ISONAS provides pure IP access control solutions.